@@ -64,6 +64,12 @@ class Test_Signatures(TestCase):
     expected_authheader = 'MAC nonce="dj83hs9s", mac="6T3zZzy2Emppni6bzL7kdRxUWL4=", id="h480djs93hd8", ts="1336363200"'
     header = ms.get_header()
     self.assertEqual(expected_authheader, header)
+  
+  def test_clearinstance(self):
+    "Tests that a fresh instance shares no data"
+    s1 = Signature(self.rfc_credentials, host="test")
+    s2 = Signature(self.rfc_credentials)
+    self.assertIsNot(s1.data, s2.data)
 
 class TestRequest(TestCase):
   "Test the sending of requests and validation against credentials"
@@ -165,6 +171,15 @@ class TestRequest(TestCase):
     response = c.get("/protected_resource", HTTP_AUTHORIZATION=header, HTTP_HOST="example.com")
     self.assertEqual(response.status_code, 200)
     self.assertEqual(response.content, "testuser")
+  
+  def test_port_in_host_header(self):
+    "Tests robustness against being passed the port in the host header"
+    s = Signature(self.rfc_credentials, method="GET", port=80, host="example.com", uri="/protected_resource")
+    header = s.get_header()
+    c = Client()
+    response = c.get("/protected_resource", HTTP_AUTHORIZATION=header, HTTP_HOST="example.com:80")
+    self.assertEqual(response.status_code, 200)
+    self.assertEqual(response.content, "testuser")  
 
 class TestUsers(TestCase):
   urls = "auth_mac.tests.urls"
@@ -257,4 +272,3 @@ class TestTimestamps(TestCase):
   
   def test_offsetregistration(self):
     "Test that using credentials fixes the associated clock offset"
-    
\ No newline at end of file
