@@ -4,7 +4,8 @@ import hmac, hashlib, base64
 from django.contrib.auth.models import User
 from auth_mac.models import Credentials, Nonce
 import re
-from auth_mac.utils import to_utc
+from auth_mac.utils import to_utc, random_string
+import random
 
 reHeader = re.compile(r"""(mac|nonce|id|ts|ext)="([^"]+)""")
 
@@ -30,11 +31,12 @@ class SignatureError(Exception):
 class Signature(object):
   "A class to ease the creation of MAC signatures"
   MAC = None
-  data = {}
+  data = None
   base_string = None
   
   def __init__(self, credentials, **kwargs):
     self.MAC = credentials
+    self.data = dict()
     self.update_data_from_dictionary(kwargs)
 
   def _add_data_item(self, from_dict, name, default=None):
@@ -67,7 +69,7 @@ class Signature(object):
     return timestamp.days * 24 * 3600 + timestamp.seconds
   
   def _get_nonce(self):
-    return User.objects.make_random_password(8)
+    return random_string(8)
 
   def validate(self):
     "Validates that we have all the required information"
@@ -208,10 +210,15 @@ class Validator(object):
     
     hostname = self.request.META["HTTP_HOST"]
     port = self.request.META["SERVER_PORT"]
+    
+    # Strip out the port from hostname, if this has been passed to us
+    if ":" in hostname:
+      hostname = hostname.split(":")[0]
+    # Form the rest of the signature
     s.update(host=hostname, port=port)
     s.update(timestamp=self.data["ts"], nonce=self.data["nonce"])
     s.update(uri=self.request.path)
-
+    s.update(method=self.request.META["REQUEST_METHOD"])
     signature = s.calculate_signature()
     
     # Compare them
